@@ -3,8 +3,7 @@ from enum import Enum, auto
 from emora_stdm.state_transition_dialogue_manager.memory import Memory
 from emora_stdm.state_transition_dialogue_manager.natex_nlu import NatexNLU
 from emora_stdm.state_transition_dialogue_manager.natex_nlg import NatexNLG
-from structpy.graph.labeled_digraph import MapMultidigraph
-import structpy
+from emora_stdm.state_transition_dialogue_manager.database import GraphDatabase
 from typing import Union, Set, List, Dict, Callable, Tuple, NoReturn
 from emora_stdm.state_transition_dialogue_manager.utilities import AlterationTrackingDict
 from emora_stdm.state_transition_dialogue_manager.ngrams import Ngrams
@@ -49,7 +48,7 @@ class DialogueFlow:
 
     def __init__(self, initial_state: Union[Enum, str, tuple], initial_speaker = Speaker.SYSTEM,
                  macros: Dict[str, Macro] =None, kb: Union[KnowledgeBase, str, List[str]] =None):
-        self._graph = structpy.graph.database.Database(MapMultidigraph)()
+        self._graph = GraphDatabase()
         self._initial_state = State(initial_state)
         self._state = self._initial_state
         self._potential_transition = None
